@@ -77,10 +77,8 @@ my $strict_checking = defined $option{strict_checking}
     ? $option{strict_checking} : 0;
 Geo::BUFR->set_strict_checking($strict_checking);
 
-# Set verbosity level for the BUFR module. Must be set also for each
-# BUFR object generated
-my $verbose = $option{verbose} ? $option{verbose} : 0;
-Geo::BUFR->set_verbose($verbose);
+# Set verbosity level
+Geo::BUFR->set_verbose($option{verbose}) if $option{verbose};
 
 # Set BUFR table path
 if ($option{tablepath}) {
@@ -136,7 +134,6 @@ while (my $msg = <$IN>) {
 
     $/ = $oldeol;
     my $bufr = Geo::BUFR->new($msg);
-    $bufr->set_verbose($verbose);
 
     $out .= alter($bufr);
     $out .= $rest;
